==> trytond-module-account_stock_continental-2.0.0.tgz: lib/python2.7/site-packages/trytond/modules/account_stock_continental/tests/test_account_stock_continental.py <==
#!/usr/bin/env python
#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.

import sys, os
DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
    '..', '..', '..', '..', '..', 'trytond')))
if os.path.isdir(DIR):
    sys.path.insert(0, os.path.dirname(DIR))

import unittest
import doctest
import trytond.tests.test_tryton
from trytond.tests.test_tryton import test_view
from trytond.backend.sqlite.database import Database as SQLiteDatabase


class AccountStockContinentalTestCase(unittest.TestCase):
    '''
    Test Account Stock Continental module.
    '''

    def setUp(self):
        trytond.tests.test_tryton.install_module('account_stock_continental')

    def test0005views(self):
        '''
        Test views.
        '''
        test_view('account_stock_continental')

def doctest_dropdb(test):
    '''
    Remove sqlite memory database
    '''
    database = SQLiteDatabase().connect()
    cursor = database.cursor(autocommit=True)
    try:
        database.drop(cursor, ':memory:')
        cursor.commit()
    finally:
        cursor.close()

def suite():
    suite = trytond.tests.test_tryton.suite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
        AccountStockContinentalTestCase))
    suite.addTests(doctest.DocFileSuite('scenario_account_stock_continental.rst',
        setUp=doctest_dropdb, tearDown=doctest_dropdb, encoding='utf-8'))
    return suite

if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(suite())

==> trytond-module-account_stock_continental-2.2.0.tgz: lib/python2.7/site-packages/trytond/modules/account_stock_continental/tests/test_account_stock_continental.py <==
#!/usr/bin/env python
#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.

import sys, os
DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
    '..', '..', '..', '..', '..', 'trytond')))
if os.path.isdir(DIR):
    sys.path.insert(0, os.path.dirname(DIR))

import unittest
import doctest
import trytond.tests.test_tryton
from trytond.tests.test_tryton import test_view, test_depends
from trytond.backend.sqlite.database import Database as SQLiteDatabase


class AccountStockContinentalTestCase(unittest.TestCase):
    '''
    Test Account Stock Continental module.
    '''

    def setUp(self):
        trytond.tests.test_tryton.install_module('account_stock_continental')

    def test0005views(self):
        '''
        Test views.
        '''
        test_view('account_stock_continental')

    def test0006depends(self):
        '''
        Test depends.
        '''
        test_depends()

def doctest_dropdb(test):
    '''
    Remove sqlite memory database
    '''
    database = SQLiteDatabase().connect()
    cursor = database.cursor(autocommit=True)
    try:
        database.drop(cursor, ':memory:')
        cursor.commit()
    finally:
        cursor.close()

def suite():
    suite = trytond.tests.test_tryton.suite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
        AccountStockContinentalTestCase))
    suite.addTests(doctest.DocFileSuite('scenario_account_stock_continental.rst',
        setUp=doctest_dropdb, tearDown=doctest_dropdb, encoding='utf-8',
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
    return suite

if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(suite())
